@@ -1,13 +1,11 @@
 const path = require("path");
 const os = require("os");
 
-const { TraceMap, originalPositionFor } = require("@jridgewell/trace-mapping");
 const { validate } = require("schema-utils");
-const serialize = require("serialize-javascript");
-const { Worker } = require("jest-worker");
 
 const {
   throttleAll,
+  memoize,
   terserMinify,
   uglifyJsMinify,
   swcMinify,
@@ -26,9 +24,9 @@ const { minify } = require("./minify");
 /** @typedef {import("./utils.js").TerserOptions} TerserOptions */
 /** @typedef {import("jest-worker").Worker} JestWorker */
 /** @typedef {import("@jridgewell/trace-mapping").SourceMapInput} SourceMapInput */
+/** @typedef {import("@jridgewell/trace-mapping").TraceMap} TraceMap */
 
 /** @typedef {RegExp | string} Rule */
-
 /** @typedef {Rule[] | Rule} Rules */
 
 /**
@@ -152,6 +150,15 @@ const { minify } = require("./minify");
  * @typedef {BasePluginOptions & { minimizer: { implementation: MinimizerImplementation<T>, options: MinimizerOptions<T> } }} InternalPluginOptions
  */
 
+const getTraceMapping = memoize(() =>
+  // eslint-disable-next-line global-require
+  require("@jridgewell/trace-mapping")
+);
+const getSerializeJavascript = memoize(() =>
+  // eslint-disable-next-line global-require
+  require("serialize-javascript")
+);
+
 /**
  * @template [T=TerserOptions]
  */
@@ -254,7 +261,7 @@ class TerserPlugin {
     if (error.line) {
       const original =
         sourceMap &&
-        originalPositionFor(sourceMap, {
+        getTraceMapping().originalPositionFor(sourceMap, {
           line: error.line,
           column: error.col,
         });
@@ -397,6 +404,9 @@ class TerserPlugin {
           return initializedWorker;
         }
 
+        // eslint-disable-next-line global-require
+        const { Worker } = require("jest-worker");
+
         initializedWorker =
           /** @type {MinimizerWorker<T>} */
           (
@@ -494,7 +504,7 @@ class TerserPlugin {
 
           try {
             output = await (getWorker
-              ? getWorker().transform(serialize(options))
+              ? getWorker().transform(getSerializeJavascript()(options))
               : minify(options));
           } catch (error) {
             const hasSourceMap =
@@ -507,7 +517,7 @@ class TerserPlugin {
                   error,
                   name,
                   hasSourceMap
-                    ? new TraceMap(
+                    ? new (getTraceMapping().TraceMap)(
                         /** @type {SourceMapInput} */ (inputSourceMap)
                       )
                     : // eslint-disable-next-line no-undefined
@@ -556,7 +566,7 @@ class TerserPlugin {
                   item,
                   name,
                   hasSourceMap
-                    ? new TraceMap(
+                    ? new (getTraceMapping().TraceMap)(
                         /** @type {SourceMapInput} */ (inputSourceMap)
                       )
                     : // eslint-disable-next-line no-undefined
@@ -818,7 +828,7 @@ class TerserPlugin {
         compiler.webpack.javascript.JavascriptModulesPlugin.getCompilationHooks(
           compilation
         );
-      const data = serialize({
+      const data = getSerializeJavascript()({
         minimizer:
           typeof this.options.minimizer.implementation.getMinimizerVersion !==
           "undefined"
