@@ -755,8 +755,34 @@ esbuildMinify.getMinimizerVersion = () => {
   return packageJson && packageJson.version;
 };
 
+/**
+ * @template T
+ * @param fn {(function(): any) | undefined}
+ * @returns {function(): T}
+ */
+function memoize(fn) {
+  let cache = false;
+  /** @type {T} */
+  let result;
+
+  return () => {
+    if (cache) {
+      return result;
+    }
+    result = /** @type {function(): any} */ (fn)();
+    cache = true;
+    // Allow to clean up memory for fn
+    // and all dependent resources
+    // eslint-disable-next-line no-undefined, no-param-reassign
+    fn = undefined;
+
+    return result;
+  };
+}
+
 module.exports = {
   throttleAll,
+  memoize,
   terserMinify,
   uglifyJsMinify,
   swcMinify,
